@@ -84,8 +84,7 @@ message 1 "Exporting contents of ${SINGULARITY_CONTAINER} to ${SINGULARITY_IMAGE
 SINGULARITY_CONTAINER=`cat $SINGULARITY_CONTENTS`
 rm -r $SINGULARITY_CONTENTS
 
-#if ! eval "${SINGULARITY_bindir}"/singularity image.export "${SINGULARITY_CONTAINER}" | (cd "${SINGULARITY_ROOTFS}" && tar xBf -); then
-if ! eval "${SINGULARITY_bindir}"/singularity image.export "${SINGULARITY_CONTAINER}" | tar xBf - -C "${SINGULARITY_ROOTFS}"; then
+if ! eval "${SINGULARITY_bindir}"/singularity image.export "${SINGULARITY_CONTAINER}" | tar xf - -C "${SINGULARITY_ROOTFS}"; then
     message ERROR "Failed to export contents of ${SINGULARITY_CONTAINER} to ${SINGULARITY_ROOTFS}\n"
     rm $SINGULARITY_CONTAINER
     ABORT 255
