@@ -58,6 +58,11 @@ while true; do
             export SINGULARITY_HOME
             shift
         ;;
+        --no-home)
+            shift
+            SINGULARITY_NOHOME=1
+            export SINGULARITY_NOHOME
+        ;;
         -W|--wdir|--workdir|--workingdir)
             shift
             SINGULARITY_WORKDIR="$1"
@@ -105,6 +110,11 @@ while true; do
             SINGULARITY_UNSHARE_PID=1
             export SINGULARITY_UNSHARE_PID
         ;;
+        --noinit)
+            shift
+            SINGULARITY_NOSHIMINIT=1
+            export SINGULARITY_NOSHIMINIT
+        ;;
         -i|--ipc)
             shift
             SINGULARITY_UNSHARE_IPC=1
@@ -125,34 +135,6 @@ while true; do
             shift
             SINGULARITY_NV=1
             export SINGULARITY_NV
-            SINGULARITY_NVLIBLIST=`mktemp ${TMPDIR:-/tmp}/.singularity-nvliblist.XXXXXXXX`
-            cat $SINGULARITY_sysconfdir"/singularity/nvliblist.conf" | grep -Ev "^#|^\s*$" > $SINGULARITY_NVLIBLIST
-            for i in $(ldconfig -p | grep -f "${SINGULARITY_NVLIBLIST}"); do
-                if [ -f "$i" ]; then
-                    message 2 "Found NV library: $i\n"
-                    if [ -z "${SINGULARITY_CONTAINLIBS:-}" ]; then
-                        SINGULARITY_CONTAINLIBS="$i"
-                     else
-                        SINGULARITY_CONTAINLIBS="$SINGULARITY_CONTAINLIBS,$i"
-                    fi
-                fi
-            done
-            rm $SINGULARITY_NVLIBLIST
-            if [ -z "${SINGULARITY_CONTAINLIBS:-}" ]; then
-                message WARN "Could not find any Nvidia libraries on this host!\n";
-            else
-                export SINGULARITY_CONTAINLIBS
-            fi
-            if NVIDIA_SMI=$(which nvidia-smi 2>/dev/null); then
-                if [ -n "${SINGULARITY_BINDPATH:-}" ]; then
-                    SINGULARITY_BINDPATH="${SINGULARITY_BINDPATH},${NVIDIA_SMI}"
-                else
-                    SINGULARITY_BINDPATH="${NVIDIA_SMI}"
-                fi
-                export SINGULARITY_BINDPATH
-            else
-                message WARN "Could not find the Nvidia SMI binary to bind into container\n"
-            fi
         ;;
         -*)
             message ERROR "Unknown option: ${1:-}\n"
@@ -163,3 +145,17 @@ while true; do
         ;;
     esac
 done
+
+if [ -z "${SINGULARITY_NV_OFF:-}" ]; then # this is a "kill switch" provided for user
+    # if singularity.conf specifies --nv
+    if [ `$SINGULARITY_libexecdir/singularity/bin/get-configvals "always use nv"` == "yes" ]; then 
+        message 2 "'always use nv = yes' found in singularity.conf\n"
+        message 2 "binding nvidia files into container\n"
+        bind_nvidia_files
+    # or if the user asked for --nv    
+    elif [ -n "${SINGULARITY_NV:-}" ]; then
+        bind_nvidia_files
+    fi
+fi 
+
+
