@@ -22,6 +22,8 @@ perform publicly and display publicly, and to permit other to do so.
 '''
 
 import os
+import sys
+
 from defaults import (
     INCLUDE_CMD,
     PLUGIN_FIXPERMS
@@ -117,6 +119,19 @@ def IMPORT(image, auth=None, layerfile=None):
                                               func2=func2,
                                               tasks=tasks)
 
+        # We should receive valid filenames back, and files exist
+        # If a checksum failed for a layer we get None for that layer
+        for layer in download_layers:
+
+            if layer is None:
+                bot.abort("Error during layer download - one or more layers failed to download correctly.")  # noqa
+                sys.exit(1)
+
+            if not os.path.exists(layer):
+                bot.abort("A downloaded layer file could not be found: %s"
+                          % layer)
+                sys.exit(1)
+
     # Get Docker runscript
     runscript = extract_runscript(manifest=client.manifestv1,
                                   includecmd=INCLUDE_CMD)
