@@ -49,7 +49,6 @@ int _singularity_runtime_mount_home(void) {
     char *session_dir = singularity_registry_get("SESSIONDIR");
     char *container_dir = CONTAINER_FINALDIR;
 
-
     singularity_message(DEBUG, "Checking that home directry is configured: %s\n", home_dest);
     if ( home_dest == NULL ) {
         singularity_message(ERROR, "Could not obtain user's home directory\n");
@@ -57,6 +56,10 @@ int _singularity_runtime_mount_home(void) {
     }
 
     singularity_message(DEBUG, "Checking if home directories are being influenced by user\n");
+    if ( singularity_registry_get("NOHOME") != NULL ) {
+        singularity_message(VERBOSE, "Skipping home directory mount by user request.\n");
+        return(0);
+    }
     if ( singularity_registry_get("HOME") != NULL ) {
         singularity_message(DEBUG, "Checking if user bind control is allowed\n");
         if ( singularity_config_get_bool(USER_BIND_CONTROL) <= 0 ) {
@@ -68,7 +71,6 @@ int _singularity_runtime_mount_home(void) {
         return(0);
     }
 
-
     singularity_message(DEBUG, "Checking ownership of home directory source: %s\n", home_source);
     if ( is_owner(home_source, singularity_priv_getuid()) != 0 ) {
         singularity_message(ERROR, "Home directory is not owned by calling user: %s\n", home_source);
